@@ -1,5 +1,3 @@
-from importlib.resources import read_text
-
 from pybrary.command import Command
 
 from ..cmd.cmd import CommandCmd
@@ -8,21 +6,18 @@ from ..cmd.deploy import DeployCmd
 from ..cmd.manage import ManageCmd
 from ..cmd.method import MethodCmd
 from ..cmd.target import TargetParam
-from ..cmd.config import get_config, ConfigCmd
+from ..commands.config import get_config, ConfigCmd
 from setux.repl.repl import repl
 
 
 class UsageCmd(Command):
-    '''Usage
-    show usage
+    '''Show Usage.
     '''
     vargs = True
 
     def run(self):
-        from setux.main import banner
-        tpl = read_text('setux.cli', 'usage.tpl')
-        usage = tpl.strip().format(**locals())
-        print(usage)
+        from .usage import usage
+        print(usage())
 
 
 class MainCmd(Command):
@@ -80,6 +75,3 @@ class TopCmd(Command):
 def top():
     cmd = TopCmd()
     cmd()
-
-
-
