@@ -7,9 +7,6 @@ class Pattern(Param):
     name = 'actions_pattern'
     positional = True
 
-    def verify(self, pattern):
-        return pattern
-
 
 class Actions(Command):
     '''List Actions
