@@ -9,9 +9,6 @@ class Pattern(Param):
     name = 'commands_pattern'
     positional = True
 
-    def verify(self, pattern):
-        return pattern
-
 
 class Commands(Command):
     '''List commands
