@@ -17,7 +17,7 @@ class Level(Param):
 
 
 class Logs(Command):
-    '''Show log files
+    '''Show log files.
     '''
     Params = [
         Level,
