@@ -7,12 +7,9 @@ class Pattern(Param):
     name = 'managers_pattern'
     positional = True
 
-    def verify(self, pattern):
-        return pattern
-
 
 class Managers(Command):
-    '''List managers
+    '''List managers.
     '''
     Params = [
         Pattern,
