@@ -7,12 +7,9 @@ class Pattern(Param):
     name = 'modules_pattern'
     positional = True
 
-    def verify(self, pattern):
-        return pattern
-
 
 class Modules(Command):
-    '''List modules
+    '''List modules.
     '''
     Params = [
         Pattern,
