@@ -2,7 +2,7 @@ from pybrary.command import Command
 
 
 class OutLog(Command):
-    '''show commands log
+    '''Show commands logs.
     '''
     def run(self):
         target = self.get('target')
