@@ -2,7 +2,7 @@ from pybrary.command import Command
 
 
 class OutRun(Command):
-    '''show commands history
+    '''Show commands history.
     '''
     def run(self):
         target = self.get('target')
