@@ -2,7 +2,7 @@ from pybrary.command import Command
 
 
 class Sh(Command):
-    '''run shell cmd on target
+    '''Run shell cmd on target.
     '''
     line = True
 
