@@ -2,7 +2,7 @@ from pybrary.command import Command
 
 
 class Sudo(Command):
-    '''run shell cmd as root
+    '''Run shell cmd as root.
     '''
     line = True
 
